@@ -17,19 +17,18 @@ dict_colors = {
     'red_dark' : ('#FFFFFF', '2px solid #823535', '#efdada', '#823535')
 }
         
-def build_table(df, color, font_size = 'medium', font_family = 'Century Gothic', text_align = 'left'):
+def build_table(df, color, font_size='medium', font_family='Century Gothic, sans-serif', text_align='left', width='auto', index=False, even_color='black', even_bg_color='white'):
     if df.empty:
       return ''
      
     # Set color
     padding="0px 20px 0px 0px"
-    even_background_color = '#FFFFFF'
     color, border_bottom, odd_background_color, header_background_color = dict_colors[color]
 
     a = 0
     while a != len(df):
         if a == 0:        
-            df_html_output = df.iloc[[a]].to_html(na_rep = "", index = False, border = 0)
+            df_html_output = df.iloc[[a]].to_html(na_rep = "", index = index, border = 0)
             # change format of header
             df_html_output = df_html_output.replace('<th>'
                                                     ,'<th style = "background-color: ' + header_background_color
@@ -38,7 +37,8 @@ def build_table(df, color, font_size = 'medium', font_family = 'Century Gothic',
                                                     + ';color: ' + color
                                                     + ';text-align: ' + text_align
                                                     + ';border-bottom: ' + border_bottom
-                                                    + ';padding: ' + padding + '">')
+                                                    + ';padding: ' + padding
+                                                    + ';width: ' + str(width) + '">')
 
             #change format of table
             df_html_output = df_html_output.replace('<td>'
@@ -46,37 +46,59 @@ def build_table(df, color, font_size = 'medium', font_family = 'Century Gothic',
                                                     + ';font-family: ' + font_family
                                                     + ';font-size: ' + str(font_size)
                                                     + ';text-align: ' + text_align
-                                                    + ';padding: ' + padding + '">')
-
+                                                    + ';padding: ' + padding
+                                                    + ';width: ' + str(width) + '">')
             body = """<p>""" + format(df_html_output)
 
             a = 1
 
         elif a % 2 == 0:
-            df_html_output = df.iloc[[a]].to_html(na_rep = "", index = False, header = False)
+            df_html_output = df.iloc[[a]].to_html(na_rep = "", index = index, header = False)
              
+            # change format of index
+            df_html_output = df_html_output.replace('<th>'
+                                                    ,'<th style = "background-color: ' + odd_background_color
+                                                    + ';font-family: ' + font_family
+                                                    + ';font-size: ' + str(font_size)
+                                                    + ';text-align: ' + text_align
+                                                    + ';padding: ' + padding
+                                                    + ';width: ' + str(width) + '">')
+
             #change format of table
             df_html_output = df_html_output.replace('<td>'
                                                     ,'<td style = "background-color: ' + odd_background_color
                                                     + ';font-family: ' + font_family
                                                     + ';font-size: ' + str(font_size)
                                                     + ';text-align: ' + text_align
-                                                    + ';padding: ' + padding + '">')
+                                                    + ';padding: ' + padding
+                                                    + ';width: ' + str(width) + '">')
 
             body = body + format(df_html_output)
 
             a += 1       
 
         elif a % 2 != 0:
-            df_html_output = df.iloc[[a]].to_html(na_rep = "", index = False, header = False)
+            df_html_output = df.iloc[[a]].to_html(na_rep = "", index = index, header = False)
              
-            #change format of table
-            df_html_output = df_html_output.replace('<td>'
-                                                    ,'<td style = "background-color: ' + even_background_color
+            # change format of index
+            df_html_output = df_html_output.replace('<th>'
+                                                    ,'<th style = "background-color: ' + even_bg_color
+                                                    + '; color: ' + even_color
                                                     + ';font-family: ' + font_family
                                                     + ';font-size: ' + str(font_size)
                                                     + ';text-align: ' + text_align
-                                                    + ';padding: ' + padding + '">')
+                                                    + ';padding: ' + padding
+                                                    + ';width: ' + str(width) + '">')
+             
+            #change format of table
+            df_html_output = df_html_output.replace('<td>'
+                                                    ,'<td style = "background-color: ' + even_bg_color
+                                                    + '; color: ' + even_color
+                                                    + ';font-family: ' + font_family
+                                                    + ';font-size: ' + str(font_size)
+                                                    + ';text-align: ' + text_align
+                                                    + ';padding: ' + padding
+                                                    + ';width: ' + str(width) + '">')
 
             body = body + format(df_html_output)
 
